@@ -8,11 +8,15 @@ import (
 )
 
 var debugSet = os.Getenv("WANDER_DEBUG")
+var debugPath = os.Getenv("WANDER_DEBUG_PATH")
 
 // dev
 func Debug(msg string) {
+	if debugPath == "" {
+		debugPath = "wander.log"
+	}
 	if debugSet != "" {
-		f, err := tea.LogToFile("wander.log", "")
+		f, err := tea.LogToFile(debugPath, "")
 		if err != nil {
 			fmt.Println("fatal:", err)
 			os.Exit(1)
