@@ -17,19 +17,18 @@ var (
 )
 
 type Model struct {
-	id           int
+	ID           int
 	message      string
-	timeout      time.Duration
-	initialized  bool
+	Timeout      time.Duration
 	Visible      bool
 	MessageStyle lipgloss.Style
 }
 
 func New(message string) Model {
 	return Model{
-		id:           nextID(),
+		ID:           nextID(),
 		message:      message,
-		timeout:      constants.ToastDuration,
+		Timeout:      constants.ToastDuration,
 		Visible:      true,
 		MessageStyle: style.SuccessToast,
 	}
@@ -37,20 +36,14 @@ func New(message string) Model {
 
 func (m Model) Update(msg tea.Msg) (Model, tea.Cmd) {
 	dev.Debug(fmt.Sprintf("toast %T", msg))
-	if !m.initialized {
-		m.initialized = true
-		return m, m.timeoutAfterDuration()
-	}
-
 	switch msg := msg.(type) {
 	case TimeoutMsg:
-		if msg.ID > 0 && msg.ID != m.id {
+		if msg.ID > 0 && msg.ID != m.ID {
 			return m, nil
 		}
 
 		m.Visible = false
 	}
-
 	return m, nil
 }
 
@@ -65,18 +58,10 @@ func (m Model) ViewHeight() int {
 	return lipgloss.Height(m.View())
 }
 
-// Msg and Cmds
-
 type TimeoutMsg struct {
 	ID int
 }
 
-func (m Model) timeoutAfterDuration() tea.Cmd {
-	return tea.Tick(m.timeout, func(t time.Time) tea.Msg { return TimeoutMsg{m.id} })
-}
-
-// Helpers
-
 func nextID() int {
 	idMtx.Lock()
 	defer idMtx.Unlock()
